@@ -237,7 +237,7 @@ class HistoryModel(CustomModel, Logger):
 
     def update_label(self, index):
         tx_item = index.internalPointer().get_data()
-        tx_item['label'] = self.parent.wallet.get_label(get_item_key(tx_item))
+        tx_item['label'] = self.parent.wallet.get_label_for_txid(get_item_key(tx_item))
         topLeft = bottomRight = self.createIndex(index.row(), HistoryColumns.DESCRIPTION)
         self.dataChanged.emit(topLeft, bottomRight, [Qt.DisplayRole])
         self.parent.utxo_list.update()
@@ -269,7 +269,7 @@ class HistoryModel(CustomModel, Logger):
             self.parent.fx,
             onchain_domain=self.get_domain(),
             include_lightning=self.should_include_lightning_payments())
-        if transactions == list(self.transactions.values()):
+        if transactions == self.transactions:
             return
         old_length = self._root.childCount()
         if old_length != 0:
@@ -633,7 +633,7 @@ class HistoryList(MyTreeView, AcceptFileDragDrop):
 
     def show_transaction(self, tx_item, tx):
         tx_hash = tx_item['txid']
-        label = self.wallet.get_label(tx_hash) or None # prefer 'None' if not defined (force tx dialog to hide Description field if missing)
+        label = self.wallet.get_label_for_txid(tx_hash) or None # prefer 'None' if not defined (force tx dialog to hide Description field if missing)
         self.parent.show_transaction(tx, tx_desc=label)
 
     def add_copy_menu(self, menu, idx):
@@ -675,7 +675,6 @@ class HistoryList(MyTreeView, AcceptFileDragDrop):
         tx_URL = block_explorer_URL(self.config, 'tx', tx_hash)
         tx_details = self.wallet.get_tx_info(tx)
         is_unconfirmed = tx_details.tx_mined_status.height <= 0
-        invoice_keys = self.wallet._get_relevant_invoice_keys_for_tx(tx)
         menu = QMenu()
         if tx_details.can_remove:
             menu.addAction(_("Remove"), lambda: self.remove_local_tx(tx_hash))
@@ -699,9 +698,15 @@ class HistoryList(MyTreeView, AcceptFileDragDrop):
                 child_tx = self.wallet.cpfp(tx, 0)
                 if child_tx:
                     menu.addAction(_("Child pays for parent"), lambda: self.parent.cpfp(tx, child_tx))
-        for key in invoice_keys:
-            invoice = self.parent.wallet.get_invoice(key)
-            menu.addAction(_("View invoice"), lambda: self.parent.show_onchain_invoice(invoice))
+            if tx_details.can_dscancel and tx_details.fee is not None:
+                menu.addAction(_("Cancel (double-spend)"), lambda: self.parent.dscancel_dialog(tx))
+        invoices = self.wallet.get_relevant_invoices_for_tx(tx)
+        if len(invoices) == 1:
+            menu.addAction(_("View invoice"), lambda inv=invoices[0]: self.parent.show_onchain_invoice(inv))
+        elif len(invoices) > 1:
+            menu_invs = menu.addMenu(_("Related invoices"))
+            for inv in invoices:
+                menu_invs.addAction(_("View invoice"), lambda inv=inv: self.parent.show_onchain_invoice(inv))
         if tx_URL:
             menu.addAction(_("View on block explorer"), lambda: webopen(tx_URL))
         menu.exec_(self.viewport().mapToGlobal(position))
