@@ -44,15 +44,15 @@ import ssl
 import ipaddress
 from ipaddress import IPv4Address, IPv6Address
 import random
-import attr
+import secrets
 
+import attr
 import aiohttp
 from aiohttp_socks import ProxyConnector, ProxyType
 import aiorpcx
 from aiorpcx import TaskGroup
 import certifi
 import dns.resolver
-import ecdsa
 
 from .i18n import _
 from .logging import get_logger, Logger
@@ -119,6 +119,15 @@ class InvalidPassword(Exception):
         return _("Incorrect password")
 
 
+class AddTransactionException(Exception):
+    pass
+
+
+class UnrelatedTransactionException(AddTransactionException):
+    def __str__(self):
+        return _("Transaction is unrelated to this wallet.")
+
+
 class FileImportFailed(Exception):
     def __init__(self, message=''):
         self.message = str(message)
@@ -370,6 +379,13 @@ def json_decode(x):
     except:
         return x
 
+def json_normalize(x):
+    # note: The return value of commands, when going through the JSON-RPC interface,
+    #       is json-encoded. The encoder used there cannot handle some types, e.g. electrum.util.Satoshis.
+    # note: We should not simply do "json_encode(x)" here, as then later x would get doubly json-encoded.
+    # see #5868
+    return json_decode(json_encode(x))
+
 
 # taken from Django Source Code
 def constant_time_compare(val1, val2):
@@ -572,38 +588,24 @@ def is_hex_str(text: Any) -> bool:
     return True
 
 
-def is_non_negative_integer(val) -> bool:
-    try:
-        val = int(val)
-        if val >= 0:
-            return True
-    except:
-        pass
+def is_integer(val: Any) -> bool:
+    return isinstance(val, int)
+
+
+def is_non_negative_integer(val: Any) -> bool:
+    if is_integer(val):
+        return val >= 0
     return False
 
 
-def is_integer(val) -> bool:
-    try:
-        int(val)
-    except:
-        return False
-    else:
-        return True
+def is_int_or_float(val: Any) -> bool:
+    return isinstance(val, (int, float))
 
 
-def is_real_number(val, *, as_str: bool = False) -> bool:
-    if as_str:  # only accept str
-        if not isinstance(val, str):
-            return False
-    else:  # only accept int/float/etc.
-        if isinstance(val, str):
-            return False
-    try:
-        Decimal(val)
-    except:
-        return False
-    else:
-        return True
+def is_non_negative_int_or_float(val: Any) -> bool:
+    if is_int_or_float(val):
+        return val >= 0
+    return False
 
 
 def chunks(items, size: int):
@@ -778,7 +780,7 @@ testnet_block_explorers = {
                        {'tx': '', 'addr': ''}),
     'BlockCypher.com': ('https://live.blockcypher.com/btc-testnet/',
                        {'tx': 'tx/', 'addr': 'address/'}),
-    'Blockchain.info': ('https://www.blockchain.com/btctest/',
+    'Blockchain.info': ('https://www.blockchain.com/btc-testnet/',
                        {'tx': 'tx/', 'addr': 'address/'}),
     'Blockstream.info': ('https://blockstream.info/testnet/',
                         {'tx': 'tx/', 'addr': 'address/'}),
@@ -1304,7 +1306,9 @@ def resolve_dns_srv(host: str):
 def randrange(bound: int) -> int:
     """Return a random integer k such that 1 <= k < bound, uniformly
     distributed across that range."""
-    return ecdsa.util.randrange(bound)
+    # secrets.randbelow(bound) returns a random int: 0 <= r < bound,
+    # hence transformations:
+    return secrets.randbelow(bound - 1) + 1
 
 
 class CallbackManager:
@@ -1380,20 +1384,31 @@ class NetworkRetryManager(Generic[_NetAddrType]):
     def _on_connection_successfully_established(self, addr: _NetAddrType) -> None:
         self._last_tried_addr[addr] = time.time(), 0
 
-    def _can_retry_addr(self, peer: _NetAddrType, *,
+    def _can_retry_addr(self, addr: _NetAddrType, *,
                         now: float = None, urgent: bool = False) -> bool:
         if now is None:
             now = time.time()
-        last_time, num_attempts = self._last_tried_addr.get(peer, (0, 0))
+        last_time, num_attempts = self._last_tried_addr.get(addr, (0, 0))
         if urgent:
-            delay = min(self._max_retry_delay_urgent,
-                        self._init_retry_delay_urgent * 2 ** num_attempts)
+            max_delay = self._max_retry_delay_urgent
+            init_delay = self._init_retry_delay_urgent
         else:
-            delay = min(self._max_retry_delay_normal,
-                        self._init_retry_delay_normal * 2 ** num_attempts)
+            max_delay = self._max_retry_delay_normal
+            init_delay = self._init_retry_delay_normal
+        delay = self.__calc_delay(multiplier=init_delay, max_delay=max_delay, num_attempts=num_attempts)
         next_time = last_time + delay
         return next_time < now
 
+    @classmethod
+    def __calc_delay(cls, *, multiplier: float, max_delay: float,
+                     num_attempts: int) -> float:
+        num_attempts = min(num_attempts, 100_000)
+        try:
+            res = multiplier * 2 ** num_attempts
+        except OverflowError:
+            return max_delay
+        return max(0, min(max_delay, res))
+
     def _clear_addr_retry_times(self) -> None:
         self._last_tried_addr.clear()
 
@@ -1465,3 +1480,25 @@ def random_shuffled_copy(x: Iterable[T]) -> List[T]:
     x_copy = list(x)  # copy
     random.shuffle(x_copy)  # shuffle in-place
     return x_copy
+
+
+def test_read_write_permissions(path) -> None:
+    # note: There might already be a file at 'path'.
+    #       Make sure we do NOT overwrite/corrupt that!
+    temp_path = "%s.tmptest.%s" % (path, os.getpid())
+    echo = "fs r/w test"
+    try:
+        # test READ permissions for actual path
+        if os.path.exists(path):
+            with open(path, "rb") as f:
+                f.read(1)  # read 1 byte
+        # test R/W sanity for "similar" path
+        with open(temp_path, "w", encoding='utf-8') as f:
+            f.write(echo)
+        with open(temp_path, "r", encoding='utf-8') as f:
+            echo2 = f.read()
+        os.remove(temp_path)
+    except Exception as e:
+        raise IOError(e) from e
+    if echo != echo2:
+        raise IOError('echo sanity-check failed')
